@@ -1,6 +1,7 @@
 
 # reconstruct the equivalence class of a network.
-cpdag.backend = function(x, moral = FALSE, fix = FALSE, wlbl = TRUE, debug = FALSE) {
+cpdag.backend = function(x, moral = FALSE, fix = FALSE, wlbl = TRUE,
+    debug = FALSE) {
 
   nodes = names(x$nodes)
 
