@@ -1,13 +1,15 @@
 
 incremental.association.fdr = function(x, cluster = NULL, whitelist,
-  blacklist, test, alpha, B, max.sx = ncol(x), debug = FALSE) {
+    blacklist, test, alpha, extra.args = list(), max.sx = ncol(x),
+    debug = FALSE) {
 
   nodes = names(x)
 
   # 1. [Compute Markov Blankets]
   mb = smartSapply(cluster, as.list(nodes), ia.fdr.markov.blanket, data = x,
-         nodes = nodes, alpha = alpha, B = B, whitelist = whitelist,
-         blacklist = blacklist, test = test, max.sx = max.sx, debug = debug)
+         nodes = nodes, alpha = alpha, extra.args = extra.args,
+         whitelist = whitelist, blacklist = blacklist, test = test,
+         max.sx = max.sx, debug = debug)
   names(mb) = nodes
 
   # check markov blankets for consistency.
@@ -15,8 +17,8 @@ incremental.association.fdr = function(x, cluster = NULL, whitelist,
 
   # 2. [Compute Graph Structure]
   mb = smartSapply(cluster, as.list(nodes), neighbour, mb = mb, data = x,
-         alpha = alpha, B = B, whitelist = whitelist, blacklist = blacklist,
-         test = test, max.sx = max.sx, debug = debug)
+         alpha = alpha, extra.args = extra.args, whitelist = whitelist,
+         blacklist = blacklist, test = test, max.sx = max.sx, debug = debug)
   names(mb) = nodes
 
   # check neighbourhood sets for consistency.
@@ -26,8 +28,9 @@ incremental.association.fdr = function(x, cluster = NULL, whitelist,
 
 }#INCREMENTAL.ASSOCIATION.FDR
 
-ia.fdr.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
-  start = character(0), test, max.sx = ncol(x), debug = FALSE) {
+ia.fdr.markov.blanket = function(x, data, nodes, alpha, extra.args = list(),
+    whitelist, blacklist, start = character(0), test, max.sx = ncol(x),
+    debug = FALSE) {
 
   nodes = nodes[nodes != x]
   fdr.threshold = length(nodes) / seq_along(nodes) * sum(1 / seq_along(nodes))
@@ -104,7 +107,7 @@ ia.fdr.markov.blanket = function(x, data, nodes, alpha, B, whitelist, blacklist,
     # get an association measure for each of the available nodes.
     association = sapply(nodes, function(node) {
        indep.test(x, node, sx = setdiff(mb, node), data = data, test = test,
-         B = B, alpha = alpha)
+         extra.args = extra.args, alpha = alpha)
     })
     names(association) = nodes
 
