@@ -1,8 +1,8 @@
 
 # conditional and unconditional independence tests (vectorized in x, scalar
 # in y).
-indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1,
-  learning = TRUE) {
+indep.test = function(x, y, sx, data, test, extra.args = list(), alpha = 1,
+    learning = TRUE) {
 
   .Call(call_indep_test,
         x = x,
@@ -10,8 +10,8 @@ indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1,
         sx = sx[sx != ""],
         data = data,
         test = test,
-        B = B,
         alpha = alpha,
+        extra.args = extra.args,
         learning = learning,
         complete = attr(data, "metadata")$complete.nodes)
 
@@ -19,8 +19,8 @@ indep.test = function(x, y, sx, data, test, B = 0L, alpha = 1,
 
 # test against all possible subsets of the conditioning set (scalar in both x
 # and y).
-allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0L,
-    alpha = 1, min = 0, max = length(sx), debug = FALSE) {
+allsubs.test = function(x, y, sx, fixed = character(0), data, test,
+    extra.args = list(), alpha = 1, min = 0, max = length(sx), debug = FALSE) {
 
   .Call(call_allsubs_test,
         x = x,
@@ -29,8 +29,8 @@ allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0L,
         fixed = fixed,
         data = data,
         test = test,
-        B = B,
         alpha = alpha,
+        extra.args = extra.args,
         min = as.integer(min),
         max = as.integer(min(max, length(sx))),
         complete = attr(data, "metadata")$complete.nodes,
@@ -39,8 +39,8 @@ allsubs.test = function(x, y, sx, fixed = character(0), data, test, B = 0L,
 }#ALLSUBS.TEST
 
 # test each variable in turn given the rest as a conditioning set.
-roundrobin.test = function(x, z, fixed, data, test, B = 0L, alpha = 1,
-    debug = FALSE) {
+roundrobin.test = function(x, z, fixed, data, test, extra.args = list(),
+    alpha = 1, debug = FALSE) {
 
   if (length(z) == 0)
     return(structure(numeric(0), names = character(0)))
@@ -51,8 +51,8 @@ roundrobin.test = function(x, z, fixed, data, test, B = 0L, alpha = 1,
         fixed = fixed,
         data = data,
         test = test,
-        B = B,
         alpha = alpha,
+        extra.args = extra.args,
         complete = attr(data, "metadata")$complete.nodes,
         debug = debug)
 
