@@ -38,7 +38,6 @@ extern SEXP dedup(SEXP, SEXP, SEXP, SEXP);
 extern SEXP dpred(SEXP, SEXP, SEXP, SEXP);
 extern SEXP elist2arcs(SEXP);
 extern SEXP empty_graph(SEXP, SEXP);
-extern SEXP entropy_loss(SEXP, SEXP, SEXP);
 extern SEXP fit2arcs(SEXP);
 extern SEXP fitted_mb(SEXP, SEXP);
 extern SEXP fitted_vs_data(SEXP, SEXP, SEXP);
@@ -57,7 +56,7 @@ extern SEXP is_listed(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP is_pdag_acyclic(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP is_row_equal(SEXP, SEXP);
 extern SEXP joint_discretize(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP loglikelihood_function(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
+extern SEXP loglikelihood_function(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP lw_weights(SEXP, SEXP, SEXP, SEXP);
 extern SEXP mappred(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP marginal_discretize(SEXP, SEXP, SEXP, SEXP, SEXP);
@@ -78,7 +77,7 @@ extern SEXP ordered_graph(SEXP, SEXP, SEXP);
 extern SEXP pdag_extension(SEXP, SEXP, SEXP);
 extern SEXP pdag2dag(SEXP, SEXP);
 extern SEXP per_node_score(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
-extern SEXP rbn_master(SEXP, SEXP, SEXP, SEXP);
+extern SEXP rbn_master(SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP reset_test_counter(void);
 extern SEXP root_nodes(SEXP, SEXP);
 extern SEXP roundrobin_test(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
